@@ -72,8 +72,9 @@ def special_funcs( modname, funcname, symbol_lookup, args ):
     if not modname and funcname == 'int':
         # FIXME: should we check the type of args?  also, need we worry about the return type required
         return 'convert_int_rtz', 'int'
+
     if not modname and funcname == 'float':
-        return 'convert_double', 'double'
+        return 'convert_float', 'float'
 
     # FIXME: enforce args
     import importlib
@@ -224,8 +225,11 @@ def conv( el, symbol_lookup, declarations=None ):
         args = map( _conv, el.findall('./args/_list_element') )
         funcname, typ = special_funcs( module, funcname,  symbol_lookup, args )
 
-        # FIXME: problem here is that args could easily be a more complex expression ...
-        return '%s( %s )' % (funcname, ', '.join(a for a,t in args)), typ
+        if isinstance(funcname, basestring):
+            # FIXME: problem here is that args could easily be a more complex expression ...
+            return '%s( %s )' % (funcname, ', '.join(a for a,t in args)), typ
+
+        return funcname(', '.join(a for a,t in args)), typ
 
     if name == 'Assign':
         [target] = el.findall('./targets/_list_element')
@@ -313,13 +317,16 @@ def lambda_to_kernel( lmb, types, bindings=None ):
 
     kernel = """
 
-__kernel void sum( %(sigs)s ) {
-  int gid = get_global_id(0);
+kernel void sum( %(sigs)s ) {
+  size_t gid = get_global_id(0);
   res_g[gid] = %(body)s;
 }""" % {'sigs': sigs, 'body': kernel_body}
 
     # some platforms require this, and others complain ...
-    kernel = "#pragma OPENCL EXTENSION cl_khr_fp64 : enable\n\n" + kernel
+    kernel = """
+#pragma OPENCL EXTENSION cl_khr_fp64 : enable
+
+\n""" + kernel
 
     if bindings is None:
         kernel = "/* NOTE: without numpy bindings, some types might be incorrectly annotated as None */" + kernel
@@ -394,7 +401,10 @@ __kernel void sum( %(sig)s ) {
 }""" % {'decl': decl, 'sig': input_sig, 'body': '\n  '.join(assignments)}
 
     # some platforms require this, and others complain ...
-    kernel = "#pragma OPENCL EXTENSION cl_khr_fp64 : enable\n\n" + kernel
+    kernel = """
+#pragma OPENCL EXTENSION cl_khr_fp64 : enable
+\n""" + kernel
+
 
     if bindings is None:
         kernel = "/* NOTE: without numpy bindings, some types might be incorrectly annotated as None */" + kernel
